@@ -1,7 +1,7 @@
 from __future__ import division
 
 from numpy import sum as npsum
-from numpy import concatenate, dot, empty, sqrt, zeros
+from numpy import dot, sqrt
 from numpy_sugar.linalg import cho_solve, ddot, dotd, sum2diag
 from scipy.linalg import cho_factor
 
