@@ -3,7 +3,6 @@ from __future__ import division
 from numpy import log, pi
 from numpy.linalg import slogdet, solve
 from numpy_sugar import is_all_finite
-
 from optimix import FunctionReduce
 
 
@@ -37,11 +36,11 @@ class GP(FunctionReduce):
         >>> y = GPSampler(mean, cov).sample(random)
         >>>
         >>> gp = GP(y, mean, cov)
-        >>> print('Before: {}'.format(int(gp.feed().value())))
-        Before: -49
+        >>> print('Before: %.4f' % gp.feed().value())
+        Before: -15.5582
         >>> gp.feed().maximize(verbose=False)
-        >>> print('After: {}'.format(int(gp.feed().value())))
-        After: -49
+        >>> print('After: %.4f' % gp.feed().value())
+        After: -13.4791
     """
 
     def __init__(self, y, mean, cov):
