@@ -1,39 +1,15 @@
 from __future__ import division
 
-from numpy import all as npy_all
-from numpy import asarray, atleast_2d, dot, isfinite, log, maximum, sqrt
 from numpy import sum as npsum
-from numpy import zeros
-
+from numpy import dot, log, maximum, sqrt, zeros
 from numpy_sugar import epsilon
-from numpy_sugar.linalg import ddot, economic_svd, rsolve
+from numpy_sugar.linalg import ddot, economic_svd, rsolve, solve
 
-log2pi = log2pi = 1.837877066409345339081937709124758839607238769531250
+from ..util import log2pi
 
 
 class LMMCore(object):
     def __init__(self, y, X, QS):
-        y = asarray(y, float).ravel()
-        X = atleast_2d(asarray(X, float).T).T
-        if not npy_all(isfinite(X)):
-            msg = "Not all values are finite in the covariates matrix."
-            raise ValueError(msg)
-
-        if not npy_all(isfinite(y)):
-            raise ValueError("Not all values are finite in the outcome array.")
-
-        if not isinstance(QS, tuple):
-            raise ValueError("I was expecting a tuple for the covariance "
-                             "decomposition")
-
-        if y.shape[0] != X.shape[0]:
-            raise ValueError("Number of samples differs between outcome "
-                             "and covariates.")
-
-        if QS[0][0].shape[0] != y.shape[0]:
-            raise ValueError("Number of samples differs between outcome"
-                             " and covariance decomposition")
-
         self._QS = QS
         self._y = y
         self._scale = 1.0
@@ -59,7 +35,6 @@ class LMMCore(object):
         -------
         float
             Log of the marginal likelihood.
-
         """
         self._update()
 
@@ -90,8 +65,8 @@ class LMMCore(object):
             lml -= (n - self._QS[1].shape[0]) * log(self._D[1])
 
         d = (mTQ - yTQ for (mTQ, yTQ) in zip(self._mTQ, self._yTQ))
-        lml += sum(
-            dot(j / i, l) for (i, j, l) in zip(self._D, d, self._yTQ)) / s
+        lml += sum(dot(j / i, l)
+                   for (i, j, l) in zip(self._D, d, self._yTQ)) / s
 
         return lml / 2
 
@@ -123,14 +98,14 @@ class LMMCore(object):
     def _update_fixed_effects(self):
         yTQDiQTm = list(self._yTQDiQTm)
         mTQDiQTm = list(self._mTQDiQTm)
-        nominator = yTQDiQTm[0]
-        denominator = mTQDiQTm[0]
+        nominator = -yTQDiQTm[0]
+        denominator = -mTQDiQTm[0]
 
         if len(yTQDiQTm) > 1:
             nominator += yTQDiQTm[1]
             denominator += mTQDiQTm[1]
 
-        self._tbeta[:] = rsolve(denominator, nominator)
+        self._tbeta[:] = solve(denominator, nominator)
 
     def _update(self):
         self._update_fixed_effects()
@@ -197,10 +172,6 @@ class LMMCore(object):
         VsD = ddot(sqrt(self._svd[1]), self._svd[2], left=True)
         return rsolve(VsD, z)
 
-    @beta.setter
-    def beta(self, value):
-        self._tbeta = sqrt(self._svd[1]) * dot(self._svd[2].T, value)
-
     @property
     def delta(self):
         raise NotImplementedError
