@@ -1,9 +1,8 @@
 from __future__ import division
 
 from numpy import clip, errstate, exp, log
-from optimix import Function, Scalar, maximize_scalar
-
 from numpy_sugar import epsilon, is_all_finite
+from optimix import Function, Scalar, maximize_scalar
 
 from .core import LMMCore
 from .scan import FastScanner
@@ -39,7 +38,7 @@ class LMM(LMMCore, Function):
         >>> covariates = array([[1], [1]])
         >>> y = array([-1, 2], float)
         >>> lmm = LMM(y, covariates, QS)
-        >>> lmm.learn(verbose=False)
+        >>> lmm.fit(verbose=False)
         >>> print('%.3f' % lmm.lml())
         -3.649
 
@@ -60,11 +59,11 @@ class LMM(LMMCore, Function):
         >>> lmm.fix('scale')
         >>> lmm.delta = 0.5
         >>> lmm.scale = 1
-        >>> lmm.learn(verbose=False)
+        >>> lmm.fit(verbose=False)
         >>> print('%.3f' % lmm.lml())
         -3.832
         >>> lmm.unfix('delta')
-        >>> lmm.learn(verbose=False)
+        >>> lmm.fit(verbose=False)
         >>> print('%.3f' % lmm.lml())
         -3.713
     """
@@ -76,6 +75,9 @@ class LMM(LMMCore, Function):
         if not is_all_finite(y):
             raise ValueError("There are non-finite values in the phenotype.")
 
+        # self._fix_scale = False
+        # self._delta = 0.5
+        # self._scale = LMMCore.scale.fget(self)
         self.set_nodata()
 
     def _get_delta(self):
@@ -83,6 +85,14 @@ class LMM(LMMCore, Function):
         x = 1 / (1 + exp(-v))
         return clip(x, 1e-5, 1 - 1e-5)
 
+    @property
+    def beta(self):
+        return LMMCore.beta.fget(self)
+
+    # @beta.setter
+    # def beta(self, beta):
+    #     LMMCore.beta.fset(self, beta)
+
     def copy(self):
         r"""Return a copy of this object.
 
@@ -101,8 +111,9 @@ class LMM(LMMCore, Function):
         Function.__init__(
             o, logistic=Scalar(self.variables().get('logistic').value))
 
-        setattr(o, '_fix_scale', self._fix_scale)
-        setattr(o, '_scale', self._scale)
+        o._fix_scale = self._fix_scale
+        # o._delta = self._delta
+        o._scale = self._scale
 
         o.set_nodata()
         return o
@@ -163,7 +174,7 @@ class LMM(LMMCore, Function):
         """
         return self.scale * self.delta
 
-    def learn(self, verbose=True):
+    def fit(self, verbose=True):
         r"""Maximise the marginal likelihood.
 
         Parameters
@@ -260,7 +271,7 @@ class LMM(LMMCore, Function):
         else:
             self._fix_scale = False
 
-    def value(self, *_):
+    def value(self):
         self.delta = self._get_delta()
         return self.lml()
 
@@ -271,20 +282,3 @@ class LMM(LMMCore, Function):
     @X.setter
     def X(self, X):
         LMMCore.X.fset(self, X)
-
-    def gradient(self, *_):
-        raise NotImplementedError
-
-    @property
-    def heritability(self):
-        t = (self.fixed_effects_variance + self.genetic_variance +
-             self.environmental_variance)
-        return self.genetic_variance / t
-
-    @property
-    def genetic_variance(self):
-        return self.scale * (1 - self.delta)
-
-    @property
-    def environmental_variance(self):
-        return self.scale * self.delta
